jactorch.nn.gumbel\_softmax
===========================

.. automodule:: jactorch.nn.gumbel_softmax

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   functional
   softmax









